==> haskell-hslua-repl-0.1.2-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-7dUN2dqBRsWFwJdNSfsco5
key:                  hslua-repl-0.1.2-7dUN2dqBRsWFwJdNSfsco5
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  276c7be496cfc53395d70829af511ed3
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-7dUN2dqBRsWFwJdNSfsco5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-AnALG2zDVxa3Cx4hZfOiZK
    isocline-1.0.9-IBnHwK5smnT23zzRSM2Fhz
    lua-2.3.3-HWqV5OauNQk3ayYX4UoAy7 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-repl-0.1.2-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-F7iwbYsMoaDDwNvHx8mxSv
key:                  hslua-repl-0.1.2-F7iwbYsMoaDDwNvHx8mxSv
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  fb0d4605b9c75b00985a0981c9b3d855
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-F7iwbYsMoaDDwNvHx8mxSv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-42MeyWskp7m28w9nbHTnSC
    isocline-1.0.9-IBnHwK5smnT23zzRSM2Fhz
    lua-2.3.3-HWqV5OauNQk3ayYX4UoAy7 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
